@@ -43,74 +43,73 @@ const char *expect[MAX_DIGIT + 1][MAX_ITER] = {
   {},
   /* digit 6 */
   {
-    /* The first ten of these match the values in RFC 4226. */
-    "755224",
-    "287082",
-    "359152",
-    "969429",
-    "338314",
-    "254676",
-    "287922",
-    "162583",
-    "399871",
-    "520489",
-    "403154",
-    "481090",
-    "868912",
-    "736127",
-    "229903",
-    "436521",
-    "186581",
-    "447589",
-    "903435",
-    "578337"
-  },
+   /* The first ten of these match the values in RFC 4226. */
+   "755224",
+   "287082",
+   "359152",
+   "969429",
+   "338314",
+   "254676",
+   "287922",
+   "162583",
+   "399871",
+   "520489",
+   "403154",
+   "481090",
+   "868912",
+   "736127",
+   "229903",
+   "436521",
+   "186581",
+   "447589",
+   "903435",
+   "578337"},
   /* digit 7 */
   {
-    "4755224",
-    "4287082",
-    "7359152",
-    "6969429",
-    "0338314",
-    "8254676",
-    "8287922",
-    "2162583",
-    "3399871",
-    "5520489",
-    "2403154",
-    "3481090",
-    "7868912",
-    "3736127",
-    "5229903",
-    "3436521",
-    "2186581",
-    "4447589",
-    "1903435",
-    "1578337",
-  },
+   "4755224",
+   "4287082",
+   "7359152",
+   "6969429",
+   "0338314",
+   "8254676",
+   "8287922",
+   "2162583",
+   "3399871",
+   "5520489",
+   "2403154",
+   "3481090",
+   "7868912",
+   "3736127",
+   "5229903",
+   "3436521",
+   "2186581",
+   "4447589",
+   "1903435",
+   "1578337",
+   },
   /* digit 8 */
   {
-    "84755224",
-    "94287082",
-    "37359152",
-    "26969429",
-    "40338314",
-    "68254676",
-    "18287922",
-    "82162583",
-    "73399871",
-    "45520489",
-    "72403154",
-    "43481090",
-    "47868912",
-    "33736127",
-    "35229903",
-    "23436521",
-    "22186581",
-    "94447589",
-    "71903435",
-    "21578337",
-  }
+   "84755224",
+   "94287082",
+   "37359152",
+   "26969429",
+   "40338314",
+   "68254676",
+   "18287922",
+   "82162583",
+   "73399871",
+   "45520489",
+   "72403154",
+   "43481090",
+   "47868912",
+   "33736127",
+   "35229903",
+   "23436521",
+   "22186581",
+   "94447589",
+   "71903435",
+   "21578337",
+   }
 };
 
 int
@@ -136,7 +135,7 @@ main (void)
     for (moving_factor = 0; moving_factor < MAX_ITER; moving_factor++)
       {
 	rc = oath_hotp_generate (secret, secretlen, moving_factor,
-				digits, false, OATH_HOTP_DYNAMIC_TRUNCATION,
+				 digits, false, OATH_HOTP_DYNAMIC_TRUNCATION,
 				 otp);
 	if (rc != OATH_OK)
 	  {
@@ -176,7 +175,7 @@ main (void)
   for (digits = 0; digits < 6; digits++)
     {
       rc = oath_hotp_generate (secret, secretlen, moving_factor,
-			      digits, false, OATH_HOTP_DYNAMIC_TRUNCATION,
+			       digits, false, OATH_HOTP_DYNAMIC_TRUNCATION,
 			       otp);
       if (rc != OATH_INVALID_DIGITS)
 	{
@@ -187,7 +186,7 @@ main (void)
   for (digits = 9; digits < 15; digits++)
     {
       rc = oath_hotp_generate (secret, secretlen, moving_factor,
-			      digits, false, OATH_HOTP_DYNAMIC_TRUNCATION,
+			       digits, false, OATH_HOTP_DYNAMIC_TRUNCATION,
 			       otp);
       if (rc != OATH_INVALID_DIGITS)
 	{
